From 453d00938139cb773ebe7def47d0d46ba595ef99 Mon Sep 17 00:00:00 2001
From: Raghav Gururajan <raghavgururajan@disroot.org>
Date: Fri, 27 Mar 2020 18:24:29 -0400
Subject: [PATCH 4/4] gnu: packages: crypto: Add libdecaf

* gnu/packages/crypto.scm (libdecaf): New variable.
---
 gnu/packages/crypto.scm | 39 +++++++++++++++++++++++++++++++++++++++
 1 file changed, 39 insertions(+)

diff --git a/gnu/packages/crypto.scm b/gnu/packages/crypto.scm
index afe85ae497..014e40cdaf 100644
--- a/gnu/packages/crypto.scm
+++ b/gnu/packages/crypto.scm
@@ -15,6 +15,7 @@
 ;;; Copyright © 2019 Pierre Neidhardt <mail@ambrevar.xyz>
 ;;; Copyright © 2019 Tanguy Le Carrour <tanguy@bioneland.org>
 ;;; Copyright © 2020 Jakub Kądziołka <kuba@kadziolka.net>
+;;; Copyright © 2020 Raghav Gururajan <raghavgururajan@disroot.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -41,8 +42,10 @@
   #:use-module (gnu packages check)
   #:use-module (gnu packages compression)
   #:use-module (gnu packages cryptsetup)
+  #:use-module (gnu packages documentation)
   #:use-module (gnu packages gettext)
   #:use-module (gnu packages gnupg)
+  #:use-module (gnu packages graphviz)
   #:use-module (gnu packages image)
   #:use-module (gnu packages kerberos)
   #:use-module (gnu packages libbsd)
@@ -75,6 +78,42 @@
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26))
 
+(define-public libdecaf
+ (package
+  (name "libdecaf")
+  (version "1.0")
+  (source
+   (origin
+    (method git-fetch)
+    (uri
+     (git-reference
+      (url "https://git.code.sf.net/p/ed448goldilocks/code")
+      (commit
+       (string-append "v" version))))
+    (file-name
+     (git-file-name name version))
+    (sha256
+     (base32 "1xr13pibx1c0gbjmir7rwyj7y2bwr6pmkysdl66w3yvjmvxipvk0"))))
+  (build-system cmake-build-system)
+  (arguments
+   '(#:configure-flags
+     (list
+      "-DENABLE_SHARED=ON"
+      "-DENABLE_STATIC=ON"
+      "-DENABLE_STRICT=YES"
+      "-DENABLE_TESTS=YES"
+      "-DGENERATED_SOURCE_PATH=OFF")))
+  (native-inputs
+   `(("dot" ,graphviz)
+     ("doxygen" ,doxygen)
+     ("python" ,python-2.7)))
+  (synopsis "Decaf Elliptic Curve Library")
+  (description "The libdecaf library is an implementation of elliptic curve
+cryptography using the Montgomery and Edwards curves Curve25519, Ed25519,
+Ed448-Goldilocks and Curve448, using the Decaf encoding.")
+  (home-page "http://ed448goldilocks.sourceforge.net/")
+  (license license:expat)))
+
 (define-public libsodium
   (package
     (name "libsodium")
-- 
2.26.0

